pictool - Random collection of useful things you can do with images
===================================================================
.. image:: https://travis-ci.org/toabctl/pictool.svg
    :target: https://travis-ci.org/toabctl/pictool

`pictool` is a command line program for manipulating and altering images.

Installation
------------
For running `pictool`, opencv_ and gexiv2_ need to be installed. Usually, both
are included in different distributions (like openSUSE_ or Debian_) and can
be installed via the available package manager (like `zypper` or `apt`).

When the requirements are installed, you can install `pictool` via `pip`::

  pip install pictool


.. _opencv: https://opencv.org/
.. _gexiv2: https://wiki.gnome.org/Projects/gexiv2
.. _openSUSE: https://opensuse.org/
.. _Debian: https://www.debian.org/
